Hazelnut - Terminal-based automated file organizer
A Hazel-like file organization tool with a TUI interface.
Re-exports
pub use config::Config;pub use rules::Action;pub use rules::Condition;pub use rules::Rule;pub use rules::RuleEngine;pub use theme::Theme;pub use watcher::Watcher;
Modules
- app
- TUI Application module
- config
- Configuration management
- ipc
- Inter-process communication between TUI and daemon
- rules
- Rule engine - conditions and actions for file organization
- theme
- Theme configuration and colors.
- watcher
- File system watcher
Enums
- Package
Manager - Detected package manager for installation
- Version
Check - Result of a version check
Constants
- VERSION
- Current version from Cargo.toml
Functions
- check_
for_ updates - Check if a newer version is available on GitHub
- check_
for_ updates_ timeout - Check if a newer version is available on GitHub with custom timeout
- detect_
package_ manager - Detect how hazelnut was installed
- expand_
path - Expand ~ in a path to the user’s home directory
- run_
update - Run the update command and return the result